#ifndef TIME_SAVERS_H
#define TIME_SAVERS_H

void TimeSavers_Register();

// SkipCutscene
    // Story
        void SkipBlueWarp_Register();
        void SkipDekuTreeIntro_Register();
        void SkipLostWoodsBridge_Register();
        void SkipToGivingZeldasLetter_Register();
        void SkipZeldaFleeingCastle_Register();
    void SkipIntro_Register();
// SkipMiscInteractions
    void MoveJabuJabuElevator_Register();
    void MoveMidoInKokiriForest_Register();
    void SkipChildRutoInteractions_Register();
void FasterHeavyBlockLift_Register();
void FasterRupeeAccumulator_Register();

#endif // TIME_SAVERS_H
